==> haskell-config-value-0.8.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-value.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-value
version:              0.8.1
visibility:           public
id:                   config-value-0.8.1-CPHuhX6Th8uAEkzmCpZEqk
key:                  config-value-0.8.1-CPHuhX6Th8uAEkzmCpZEqk
license:              MIT
copyright:            2015-2016,2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-value
synopsis:             Simple, layout-based value language similar to YAML or JSON
description:
    This package implements a language similar to YAML or JSON but
    with fewer special cases and fewer dependencies. It emphasizes
    layout structure for sections and lists, and requires quotes
    around strings.

category:             Language
abi:                  16aee9da79b718ecb1d7ce95b5d6b2aa
exposed:              True
exposed-modules:      Config Config.Lens Config.Macro Config.Number
hidden-modules:
    Config.Lexer Config.LexerUtils Config.Parser Config.NumberParser
    Config.Tokens Config.Pretty Config.Value

import-dirs:          /usr/lib/ghc-8.10.4/site-local/config-value-0.8.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/config-value-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/config-value-0.8.1
hs-libraries:         HSconfig-value-0.8.1-CPHuhX6Th8uAEkzmCpZEqk
depends:
    array-0.5.4.0 base-4.14.1.0 containers-0.6.2.1 pretty-1.1.3.6
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-config-value/html/config-value.haddock

haddock-html:         /usr/share/doc/haskell-config-value/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-value-0.8.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-value.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 config-value
version:              0.8.1
visibility:           public
id:                   config-value-0.8.1-G5DQMqzxLAIEt1XZ4gJ1e4
key:                  config-value-0.8.1-G5DQMqzxLAIEt1XZ4gJ1e4
license:              MIT
copyright:            2015-2016,2019 Eric Mertens
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-value
synopsis:             Simple, layout-based value language similar to YAML or JSON
description:
    This package implements a language similar to YAML or JSON but
    with fewer special cases and fewer dependencies. It emphasizes
    layout structure for sections and lists, and requires quotes
    around strings.

category:             Language
abi:                  fc81e7fb59d07d383be9a59ced1dcf5f
exposed:              True
exposed-modules:      Config Config.Lens Config.Macro Config.Number
hidden-modules:
    Config.Lexer Config.LexerUtils Config.Parser Config.NumberParser
    Config.Tokens Config.Pretty Config.Value

import-dirs:          /usr/lib/ghc-8.10.5/site-local/config-value-0.8.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/config-value-0.8.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/config-value-0.8.1
hs-libraries:         HSconfig-value-0.8.1-G5DQMqzxLAIEt1XZ4gJ1e4
depends:
    array-0.5.4.0 base-4.14.2.0 containers-0.6.4.1 pretty-1.1.3.6
    text-1.2.4.1

haddock-interfaces:
    /usr/share/doc/haskell-config-value/html/config-value.haddock

haddock-html:         /usr/share/doc/haskell-config-value/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
